<?php
$lang['abbr_length'] = 'P';
$lang['abbr_width'] = 'L';
$lang['abbr_height'] = 'A';
$lang['add'] = 'Aggiungere';
$lang['addcategory'] = 'Aggiungere una categoria';
$lang['addfielddef'] = 'Aggiungere un campo';
$lang['adjustable'] = 'Modificabile';
$lang['addproduct'] = 'Aggiungere un Prodotto';
$lang['add_attrib_set'] = 'Aggiungere un attributo';
$lang['add_category_field'] = 'Associa campo con categoria: &quot;%s&quot;';
$lang['add_hierarchy_item'] = 'Aggiungere un Item gerarchico';
$lang['add_option'] = 'Aggiungere una opzione attributo';
$lang['admin_only'] = 'Solo l&#039;admin pu&ograve; vere questo attributo?';
$lang['align_ul'] = 'Alto Sinistro';
$lang['align_uc'] = 'Alto Centrato';
$lang['align_ur'] = 'Alto Destro';
$lang['align_ml'] = 'Medio Sinistro';
$lang['align_mc'] = 'Centrato';
$lang['align_mr'] = 'Medio Destro';
$lang['align_ll'] = 'Basso Sinistro';
$lang['align_lc'] = 'Basso Centrato';
$lang['align_lr'] = 'Basso Destro';
$lang['all'] = 'Tutti';
$lang['allcategories'] = 'Tutte le categorie';
$lang['any'] = 'Qualsiasi';
$lang['areyousure'] = 'Siete sicuri?';
$lang['areyousure_deleteproduct'] = 'Siete sicuro di voler proprio cancellare questo prodotto e tutte le informazioni correlate?';
$lang['ascending'] = 'Ascendente';
$lang['attribute_name'] = 'Nome attributo';
$lang['automatic'] = 'Automatico';
$lang['byhierarchytemplates'] = 'Modelli Report gerarchici';
$lang['byhierarchytemplate_addedit'] = 'Aggiungere/Modifica un Modello Report gerarchico';
$lang['cancel'] = 'Cancella';
$lang['categories'] = 'Categorie';
$lang['category'] = 'Categoria';
$lang['categoryexists'] = 'Una categoria con quel nome gi&agrave; esiste';
$lang['categorylisttemplates'] = 'Modelli Lista categorie';
$lang['categorylisttemplate_addedit'] = 'Aggiungere/Modifica un Modello ListaCategorie';
$lang['centimeters'] = 'Centimetri';
$lang['checkbox'] = 'Checkbox ';
$lang['confirm_copyattributes'] = 'Tutti l&#039;insieme di attributi per questo prodotto sar&agrave; rimosso. Siete sicuro di voler continuare?';
$lang['confirm_delete_hierarchy_node'] = 'Siete sicuro di voler proprio cancellare questo nodo? Tutti i prodotti che stanno usando questo nodo non saranno pi&ugrave; gerarchici';
$lang['confirm_import'] = 'Siete veramente sicuri di voler fare questo?\n\nConfigurazioni non corrette o un file di configurazione non valido potrebbero corrompere il sistema.';
$lang['copy'] = 'Copia';
$lang['copy_attrib_sets'] = 'Copia l&#039;insieme degli Attributi';
$lang['copy_category'] = 'Copia Categoria';
$lang['createddate'] = 'Data di creazione';
$lang['current_value'] = 'Valore corrente';
$lang['data'] = 'Data ';
$lang['default'] = 'Predefinito';
$lang['defaulttemplates'] = 'Modelli predefiniti';
$lang['default_template_notice'] = '<strong>Nota:</strong> Il contenuto di queste aree testo sono usate per determinare il contenuto predefinito dei Modelli quando scegliete &quot;Aggiungere Modello&quot; nell&#039;appropriato tab. Modificando una di queste aree testo non avranno nessun effetto sul vostro sito.';
$lang['delete'] = 'Cancella';
$lang['delete_attribset'] = 'Cancella attributo';
$lang['delete_hierarchy_item'] = 'Cancella un Item gerarchico';
$lang['descending'] = 'Discendente';
$lang['description'] = 'Descrizione';
$lang['destination'] = 'Destinazione';
$lang['details'] = 'Dettagli';
$lang['detailtemplates'] = 'Modelli Dettaglio';
$lang['detailtemplate_addedit'] = 'Aggiungere/Modifica un Modello Dettaglio';
$lang['dimensions'] = 'Dimensioni';
$lang['disabled'] = 'Disabilitato';
$lang['down'] = 'Muovi gi&ugrave;';
$lang['draft'] = 'Bozza';
$lang['dropdown'] = 'Tendina';
$lang['dropdown_options'] = 'Opzioni Tendina <em>(applicabile solo per campi dropdown)</em><br/><br/><em>(un termine per ogni riga)</em>';
$lang['edit'] = 'Modifica';
$lang['edit_attribset'] = 'Modifica Attributo';
$lang['edit_attribsets'] = 'Modifica settaggi Attributo';
$lang['edit_attribsets_for'] = 'Modifica settaggi Attributo per';
$lang['edit_attributes'] = 'Modifica Attributi';
$lang['edit_category'] = 'Modifica Categoria';
$lang['edit_category_fields'] = 'Modifica campi della Categoria';
$lang['edit_hierarchy_item'] = 'Modifica un Item gerarchico';
$lang['error_attribset_exists'] = 'Un attributo con quel nome gi&agrave; esiste';
$lang['error_duplicate_sku'] = 'Duplica il valore SKU trovato';
$lang['error_fieldvalue_empty'] = 'Il valore del campo non pu&ograve; essere vuoto';
$lang['error_fileformat'] = 'Problema nel formato File';
$lang['error_filenotfound'] = 'File non trovato';
$lang['error_fileopen'] = 'Problema nell&#039;apertura del File %s';
$lang['error_invalidparent'] = 'Parent invalido (un nodo gerarchico non pu&ograve; essere il proprio parent)';
$lang['error_invalid_name'] = 'Il valore del campo personalizzato non &egrave; valido (contiene caratteri non alfanumerici)';
$lang['error_invalid_value'] = 'Value specificato non valido';
$lang['error_missingparam'] = 'Un parametro richiesto &egrave; mancante o non valido';
$lang['error_nameused'] = 'Un item con quel nome &egrave; gi&agrave; in uso';
$lang['error_nofieldtype'] = 'Si prega si selezionare il tipo di campo';
$lang['error_noname'] = 'Tu devi aggiungere un nome';
$lang['error_onesubscriptionfield'] = 'Solo un campo di sottoscrizione &egrave; permesso';
$lang['error_permissiondenied'] = 'Permesso negato';
$lang['error_product_aliasused'] = 'Lo specificato alias &egrave; gi&agrave; in uso';
$lang['error_product_nameused'] = 'Un Prodotto con quel nome gi&agrave; esiste';
$lang['error_product_notfound'] = 'il prodotto richiesto non pu&ograve; essere trovato';
$lang['error_product_skuused'] = 'Il valore di SKU &egrave; gi&agrave; in uso da un&#039;altro prodotto';
$lang['error_price_adjustment'] = 'Valore del prezzo di adeguamento non valido per il termine %s';
$lang['error_upload_failed'] = 'Upload fallito: %s';
$lang['expire_six_months'] = 'Dopo 6 Mesi';
$lang['expire_one_year'] = 'Dopo 1 anno';
$lang['expire_two_year'] = 'Dopo 2 anni';
$lang['extra1'] = 'Campo Extra 1';
$lang['extra2'] = 'Campo Extra 2';
$lang['field'] = 'Campo';
$lang['fielddef'] = 'Definizione Campo';
$lang['fielddefs'] = 'Definizioni Campo';
$lang['file'] = 'File ';
$lang['filters'] = 'Filtri';
$lang['firstpage'] = '<<';
$lang['general_settings'] = 'Configurazioni generali';
$lang['go'] = 'Vai';
$lang['hierarchy'] = 'Gerarchia';
$lang['hierarchy_position'] = 'Posizione gerarchia';
$lang['hierarchy_settings'] = 'Configurazioni della Gerarchia';
$lang['id'] = 'ID';
$lang['imagetext'] = 'Immagine';
$lang['image_handling_settings'] = 'Configurazione Immagini';
$lang['import_from_csv'] = 'Prodotti importati da file CSV';
$lang['inches'] = 'Pollici';
$lang['include_children'] = 'Includo Figli?';
$lang['info_alnumonly'] = 'Solo caratteri alfanumerici. No spazi, virgolette, apici o combinazioni lettere/numeri';
$lang['info_attribtemplate'] = 'Valori possibili sono: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
$lang['info_attributes_copied'] = 'Attributi Copiati';
$lang['info_autowatermark'] = 'Configurazione dei Watermark sono prese dal modulo CGExtensions';
$lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
$lang['info_cart_module_params'] = 'Questi parametri sono dati al modulo Carrello selezionato dal dettaglio prodotti e visualizzazione sommario';
$lang['info_copy_attribsets'] = 'Questa azione copier&agrave; l&#039;insieme degli Attributi (escludendo i valori sku) da un altro prodotto.';
$lang['info_createfields'] = 'Creo automaticamente campi prodotti senza nome? <em>(Saranno creati come campi testo)</em>';
$lang['info_createcategories'] = 'Automaticamente creo categorie produtto che coincidono con quelle del file CSV, se non esistono ancora';
$lang['info_createhierarchy'] = 'Automaticamente creo gerarchie produtto che coincidono con quelle del file CSV, se non esistono ancora';
$lang['info_decimal_units'] = 'Questo sistema capisce il punto (.) come separatore decimale. ad esempio: <strong>5.25</strong>';
$lang['info_delimiter'] = 'Specifica il carattere (o caratteri) che separano ciascun campo';
$lang['info_duplicateproducts'] = 'Specifica come il sistema dovrebbe tenere un prodotto quando il nome sempre esiste nel file CSV';
$lang['info_fielddefs_tab'] = '<strong>Nota:</strong> Tutti i Campi qua definiti sono utilizzabili per tutti i prodotti.';
$lang['info_fieldproblems'] = 'Problema con uno o pi&ugrave; dei campi personalizzati. L&#039;azione ha terminato con successo, tuttavia voi dovreste investigare e correggere questi problemi';
$lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
$lang['info_hierpage'] = 'Usa questa pagina per la visualizzazione gerarchica.  Il pageid non sar&agrave; specificato nell&#039;URL.';
$lang['info_imagepath'] = 'Il path (relativo alla directory di uploads) dove le immagini, riferite al file di importazione, possono essere trovate';
$lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
$lang['info_price_adjustment'] = 'Valori validi sono +-*#.##';
$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
$lang['info_publicfield'] = 'Campi pubblici sono utilizzabili per il pubblico da vedere';
$lang['label'] = 'Etichetta';
$lang['label_skip'] = 'Salta';
$lang['label_overwrite'] = 'Sovrascrivo';
$lang['lastpage'] = '>>';
$lang['last_modified'] = 'Ultima modifica';
$lang['logotext'] = 'Seconda immagine';
$lang['maxlength'] = 'Massima lunghezza <em>(applicabile solo su campi textbox)</em>';
$lang['modifieddate'] = 'Data di modifica';
$lang['module_description'] = 'Un modulo per gestire un catalogo di prodotti, loro prezzi, immagini, etc, e permette agli utenti di costruire un carrello';
$lang['move_down'] = 'Muovi gi&ugrave;';
$lang['move_up'] = 'Muovi su';
$lang['name'] = 'Nome';
$lang['needpermission'] = 'Non avete i permessi richiesti: %s';
$lang['new_category_name'] = 'Nuovo nome Categoria';
$lang['nextpage'] = '>';
$lang['no'] = 'No ';
$lang['nonamegiven'] = 'Nessun nome inserito';
$lang['none'] = 'Nessuno';
$lang['of'] = 'di';
$lang['page'] = 'Pagina';
$lang['page_of'] = 'Pagina %s di %s';
$lang['page_limit'] = 'Limite pagina';
$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
<ul>
  <li>hierarchy -- Display a product list by hierarchy</li>
  <li>categorylist - Display a list of product categories</li>
  <li><em>default</em> - Display a summary of products</li>
  <li>details - Display a detail view of a single product</li>
  <li>fieldlist - Display a list of values from a specified field.
     <p>
 - This action can be used to create a navigation from the values of a specific field.  i.e:  you could create a custom dropdown field called &quot;color&quot; and then create a navigation based on the different colors.
     </p>
  </li>
  <li>search - Display a form to allow searching products on various criterium</li>
</ul>';
$lang['param_category'] = 'Quando usato nel modo <em>default</em> sommario, questo parametro, dovrebbe corrispondere col nome di una categoria esistente usata per visualizzare solo quei termini che sono in quella categoria. (pu&ograve; essere fornita una lista separata da virgola)';
$lang['param_categorylisttemplate'] = 'Utile solo con l&#039;azione categorylist, questo parametro indica il Modello che dovrebbe essere utilizzato per la visualizzazione. Se nessun valore &egrave; specificato allora &egrave; usato il Modello predefinito corrente di quel tipo.';
$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
$lang['param_detailpage'] = 'Questo specifica il ID di pagina o alias che dovrebbe essere usato per visualizzare il report dettaglio.';
$lang['param_detailtemplate'] = 'Questo parametro specifica il Modello che dovrebbe essere usato per la visualizzazione dettaglio. Se nessun valore &egrave; specificato, allora sar&agrave; usato il Modello predefinito del tipo corrente.';
$lang['param_field'] = 'Usato solo nel <em>fieldlist</em> questo parametro &egrave; richiesto per specificare il nome di un user defined property per creare una lista.';
$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
$lang['param_hierarchy'] = 'Utile solo con l&#039;azione <em>default</em>, questo parametro specifica che soloi termini nella locazione gerarchica dovrebbero essere visualizzati. Caratteri wildcard possono essere usati cos&igrave; che voi potete specificare relazioni parent/figli. Per esempio {Products hierarchy=&#039;trucks*&#039;} crea un report sommario di tutti i trucks, incluso i figli nella gerarchia. Similmente, {Products hierarchy=&#039;*trucks&#039;} visualizza un report sommario di tutti i trucks e tutti i prodotti tenuti da ogni parent nella gerarchia.';
$lang['param_hierarchytemplate'] = 'Questo parametro specifica il Modello che dovrebbe essere usato per la visualizzazione gerarchia. Se nessun valore &egrave; specificato, allora sar&agrave; usato il Modello predefinito di quel tipo.';
$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
$lang['param_pagelimit'] = 'Utile solo con l&#039;azione <em>default</em>, questo parametro specifica quanti termini dovrebbero essere visualizzati su ciascuna pagina.';
$lang['param_parent'] = 'Utile solo con l&#039;azione <em>gerarchia</em>, questo parametro specifica l&#039;id della gerarchia della locazione di partenza del report.';
$lang['param_productid'] = 'Utile solo con l&#039;azione dettaglio, questo parametro indica il prodotto che dovrebbe essere utilizzato per la visualizzazione.';
$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
$lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
$lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.  Possible values are:
<ul>
  <li><strong>asc</strong> -- Ascending order</li>
  <li>desc -- Descending order</li>
</ul>';
$lang['param_sortby'] = 'Applicable only in the summary or search actions, this parameter determines the sorting of the output products.  Possible values are:
<ul>
  <li><strong>product_name</strong></li>
  <li>id -- The product id</li>
  <li>weight -- The product weight</li>
  <li>price -- The product base price</li>
  <li>status -- Draft or published</li>
  <li>random -- Display in random order on each request</li>
  <li>created -- The creation date for this company record</li>
  <li>modified -- The modified date for this company record</li>
  <li>f:fieldname -- Allows sorting by values of custom fields.</li>
</ul>';
$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
$lang['param_summarytemplate'] = 'Questo parametro specifica il Modello che sar&agrave; utilizzato per la visualizzazione del modo sommario. Se nessun valore &egrave; specificato, allora il sar&agrave; utilizzato il Modello predefinito di quel tipo.';
$lang['parent'] = 'Padre';
$lang['postinstall'] = 'Il modulo Products &egrave; stato installato con successo';
$lang['postuninstall'] = 'Il modulo Products &egrave; stato rimosso con tutti i dati associati';
$lang['preferences'] = 'Preferenze';
$lang['preuninstall'] = 'Rimuovere questo modulo rimuover&agrave; anche tutti i dati associati, siete sicuri di voler procedere?';
$lang['price'] = 'Prezzo';
$lang['price_adjustment'] = 'Prezzo di adeguamento';
$lang['prevpage'] = '<';
$lang['product'] = 'Prodotto';
$lang['productname'] = 'Nome Prodotto';
$lang['products'] = 'Gestione Prodotto';
$lang['product_detail_settings'] = 'Configurazioni dettaglio Prodotti';
$lang['product_editing_settings'] = 'Product Editing Settings';
$lang['product_summary_settings'] = 'Product Summary Settings';
$lang['product_hierarchy'] = 'Gerarchia Prodotto';
$lang['product_manager'] = 'Gestore Prodotto';
$lang['progress'] = 'Avanzamento';
$lang['prompt'] = 'Prompt ';
$lang['prompt_add_attribset'] = 'Aggiungere/Modifica Attributi';
$lang['prompt_allowed_filetypes'] = 'Permettere l&#039;upload di files con queste estensioni (per campi tipo file)';
$lang['prompt_allowed_imagetypes'] = 'Permettere l&#039;upload di immagini con queste estensioni  (per campi tipo immagine)';
$lang['prompt_attribtemplate'] = 'Template for display of product attribute values in dropdown';
$lang['prompt_autothumbnail'] = 'Automaticamente crea miniature di immagini';
$lang['prompt_autothumbnail_size'] = 'Dimensione massima (la pi&ugrave; grande) della miniatura.';
$lang['prompt_autopreviewimg'] = 'Automaticamente crea immagini di anteprima delle immagini';
$lang['prompt_autopreviewimg_size'] = 'Dimensione massima (la pi&ugrave; grande) della immagine di anteprima.';
$lang['prompt_autowatermark'] = 'Automaticamente posiziona watermarks sulle immagini';
$lang['prompt_applicable'] = 'Abilitato per tutti i nuovi prodotti';
$lang['prompt_batchsize'] = 'Batch Size';
$lang['prompt_cart_module'] = 'Modulo Cart';
$lang['prompt_cart_module_params'] = 'Parametri del modulo Cart';
$lang['prompt_createcategories'] = 'Crea Categorie';
$lang['prompt_createfields'] = 'Creo campi Prodotto?';
$lang['prompt_createhierarchy'] = 'Crea gerarchia Prodotto';
$lang['prompt_csvfile'] = 'Upload file CSV';
$lang['prompt_currencycode'] = 'Codice per la valuta';
$lang['prompt_currencysymbol'] = 'Simbolo di valuta';
$lang['prompt_default_status'] = 'Il predefinito &egrave; che tutti i nuovi prodotti hanno questo stato';
$lang['prompt_default_taxable'] = 'Il predefinito &egrave; che tutti i nuovi prodotti hanno la tassa';
$lang['prompt_deleteproductfiles'] = 'Cancella i files associati con il prodotto quando viene cancellato?';
$lang['prompt_delimiter'] = 'Campo delimitatore';
$lang['prompt_detailpage'] = 'Pagina dettaglio predefinita';
$lang['prompt_detailsfor'] = 'Dettaglio per %s';
$lang['prompt_duplicateproducts'] = 'Come devo tenere prodotti duplicati?';
$lang['prompt_false'] = 'Falso';
$lang['prompt_handleimages'] = 'Maneggiare le immagini?';
$lang['prompt_imagepath'] = 'Path immagine';
$lang['prompt_lengthunits'] = 'Unit&agrave; di lunghezza';
$lang['prompt_notfound_behavior'] = 'Quale azione dovrebbe essere eseguita quando un prodotto non pu&ograve; essere visualizzato?';
$lang['prompt_notfound_404'] = 'Genera un errore 404';
$lang['prompt_notfound_301'] = 'Genera una redirezione 301';
$lang['prompt_notfound_errormsg'] = 'Visualizza un messaggio di errore';
$lang['prompt_notfound_msg'] = 'Messaggio di errore quando un prodotto non pu&ograve; essere trovato';
$lang['prompt_notfound_page'] = 'Pagina per fare una redirezione permanente?';
$lang['prompt_hierpage'] = 'Default Page for Hierarchy View';
$lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
$lang['prompt_prod_detailpage'] = 'Pagina predefinita per la Visualizzazione Dettaglio Produtto';
$lang['prompt_products_matching'] = 'Prodotti che combaciano con %s';
$lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
$lang['prompt_summarysortorder'] = 'Ordine predefinito nel modo sommario';
$lang['prompt_summarysorting'] = 'Campo dell&#039;ordine predefinito nel modo sommario';
$lang['prompt_template'] = 'Modello sorgente';
$lang['prompt_true'] = 'Vero';
$lang['prompt_urlprefix'] = 'Prefix to use on all URLS targeted to this this module';
$lang['prompt_use_detailpage_for_search'] = 'Use this page for search results too <em>(overrides the searchresults page parameter in the search module)</em>';
$lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
$lang['prompt_weightunits'] = 'Unit&agrave; di peso';
$lang['public'] = 'E&#039; un campo pubblico?';
$lang['published'] = 'Pubblicato';
$lang['random'] = 'Random ';
$lang['resettofactory'] = 'Azzera ai valori iniziali';
$lang['return'] = 'Ritorna';
$lang['return_to_top'] = 'Ritorna all&#039;inizio';
$lang['root'] = 'Radice';
$lang['search_description'] = 'Search Property Description';
$lang['search_expr'] = 'Should the query match all, or any of the tests below?';
$lang['search_name'] = 'Cerca nome della propriet&agrave;';
$lang['search_price'] = 'Intervallo di prezzo';
$lang['searchtemplate_addedit'] = 'Aggiuge/Modifica Modulo Search Template';
$lang['searchtemplates'] = 'Template di Ricerca';
$lang['select_one'] = 'Seleziona uno';
$lang['sku'] = 'SKU ';
$lang['sort_by'] = 'Ordine per';
$lang['sort_order'] = 'Tipo ordine';
$lang['source'] = 'Sorgente';
$lang['status'] = 'Stato';
$lang['submit'] = 'Invio';
$lang['subscription'] = 'Sottoscrizione';
$lang['subscr_expiry'] = 'Scadenza';
$lang['subscr_expiry2'] = 'Scaduti';
$lang['subscr_monthly'] = 'Mensilmente';
$lang['subscr_delperiod'] = 'Frequenza di distribuzione';
$lang['subscr_delperiod2'] = 'Distribuzione';
$lang['subscr_payperiod'] = 'Frequenza di pagamento';
$lang['subscr_payperiod2'] = 'Pagamento';
$lang['subscr_quarterly'] = 'Quadimestrale';
$lang['subscr_semianually'] = 'Semestrale';
$lang['subscr_yearly'] = 'Annuale';
$lang['summarytemplates'] = 'Modelli Sommario';
$lang['summarytemplate_addedit'] = 'Aggiungere/Modifica un Modello Sommario';
$lang['taxable'] = 'Imponibile';
$lang['test'] = 'Test ';
$lang['textarea'] = 'Text area';
$lang['textbox'] = 'Text input';
$lang['title_byhierarchy_dflttemplate'] = 'Modello nuovo Report gerarchico';
$lang['title_categorylist_dflttemplate'] = 'Modello nuovo Lista categorie predefinito';
$lang['title_detail_dflttemplate'] = 'Modello nuovo dettaglio predefinito';
$lang['title_search_dflttemplate'] = 'Nuovo Search Template predefinito';
$lang['title_summary_dflttemplate'] = 'Modello nuovo sommario predefinito';
$lang['type'] = 'Tipo';
$lang['up'] = 'Muovi su';
$lang['update'] = 'Aggiorna';
$lang['upload'] = 'Seleziona un file per upload';
$lang['url_alias'] = 'URL alias';
$lang['valid'] = 'Valido';
$lang['value'] = 'Valore';
$lang['values'] = 'Valori';
$lang['view'] = 'Visualizza';
$lang['viewable_fields'] = 'Campi Select castomizzati per visualizzare in una tabella';
$lang['watermark_location'] = 'Locazione del Watermark';
$lang['weight'] = 'Peso';
$lang['yes'] = 'S&igrave;';
$lang['utma'] = '156861353.974349155.1299072468.1299072468.1299074554.2';
$lang['utmb'] = '156861353';
$lang['utmz'] = '156861353.1299072468.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
?>
